/*
 * 
 * Copyright 2005 Sun Microsystems, Inc.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */

package net.jini.security;

import java.net.URL;

/**
 * Defines the interface for integrity verifiers used by
 * {@link Security#verifyCodebaseIntegrity Security.verifyCodebaseIntegrity},
 * allowing the URLs that provide content integrity to be extended.
 *
 * @author Sun Microsystems, Inc.
 * 
 * @since 2.0
 */
public interface IntegrityVerifier {
    /**
     * Returns <code>true</code> if the specified URL is known to provide
     * content integrity; returns <code>false</code> otherwise.
     *
     * @param url URL to verify
     * @return <code>true</code> if the specified URL is known to provide
     * content integrity; <code>false</code> otherwise
     * @throws NullPointerException if the URL is <code>null</code>
     */
    boolean providesIntegrity(URL url);
}
